package DE_EPAGES::Order::t::OrderResource;    ## no critic (RequireCommentForExportedFunctions)
use base DE_EPAGES::Shop::API::TestImportXML;

use strict;
use Data::Dumper;
use DE_EPAGES::Order::API::Resource::OrderResource;
use Test::More;

sub importXMLPath {
    return 'import.xml';
}

sub test {
    my $self = shift;
    $self->testGet();
    $self->testPut();
}

sub testGet {
    my $self = shift;

    my $Shop = $self->shop;
    my $Resource = DE_EPAGES::Order::API::Resource::OrderResource->new;

    my $hResult =
      $Resource->get( $Shop->path('TestCustomer/Orders/1234-5678') );
    is_deeply $hResult,
      {
        'orderId'        => '559A844F-864A-F463-6B84-7F000101AA71',
        'orderNumber'    => '1234-5678',
        'dispatchedDate'   => undef,
        'pendingDate' => undef,
        'closedDate' => undef,
        'dispatchedDate' => undef,
        'invoicedDate' => undef,
        'viewedDate' => undef,
        'returnedDate' => undef,
        'paidDate' => undef,
        'shippedDate' => undef,
        'archivedDate' => undef,
        'creationDate'   => '2004-01-05T00:03:00Z',
        'cancelledDate' => undef,
        'shippingAddress' => {
                                  'country' => 'DE',
                                  'zipCode' => '12345',
                                  'firstName' => undef,
                                  'salutation' => undef,
                                  'vatId' => undef,
                                  'emailAddress' => undef,
                                  'street' => 'Leutragraben 1',
                                  'state' => 'Thueringen',
                                  'city' => 'Jena',
                                  'title' => undef,
                                  'lastName' => undef,
                                  'streetDetails' => undef,
                                  'birthday' => undef,
                                  'company' => 'ePages GmbH'
                                },
        'billingAddress' => {
                                 'country' => 'DE',
                                 'zipCode' => '12345',
                                 'firstName' => undef,
                                 'salutation' => undef,
                                 'vatId' => undef,
                                 'emailAddress' => undef,
                                 'street' => 'Street Address',
                                 'state' => 'HX',
                                 'city' => 'City',
                                 'title' => undef,
                                 'lastName' => undef,
                                 'streetDetails' => undef,
                                 'birthday' => undef,
                                 'company' => 'Example Company'
                               }
      },
      'GET basic-content'
      or diag Dumper($hResult);
}

sub testPut {
    my $self = shift;
    my $DF   = DE_EPAGES::XML::API::DateTimeFormatXML->new;
    my $Shop = $self->shop;
    my $Resource = DE_EPAGES::Order::API::Resource::OrderResource->new;
    my $Order    = $Shop->path('TestCustomer/Orders/1234-5678');
    $Resource->put( $Order, { dispatchedDate => '2015-07-01T12:00:00Z' } );
    is(         $DF->format_datetime( $Order->get('DispatchedOn'), 'GMT' ),
        '2015-07-01T12:00:00Z',
        'dispatched date is set correctly' );

}

__PACKAGE__->runScript;
done_testing;
